@@ -15,35 +15,46 @@ has 'key' => (
 );
 
 has 'value' => (
-    is              => 'rw',
+    is              => 'ro',
     isa             => 'ArrayRef[Str]',
     traits          => ['Array'],
     default         => sub { [] },
-    handles => {
+    handles         => {
         add_value       => 'push',
         has_values      => 'count',
         get_value       => 'get',
+        raw_values      => 'elements',
     }
 );
 
 has 'consumed' => (
     is              => 'rw',
     isa             => 'Bool',
-    default         => 0,
+    default         => sub {0},
 );
 
 has 'type' => (
-    is              => 'rw',
+    is              => 'ro',
     isa             => 'Str',
     required        => 1,
 );
 
 has 'raw' => (
-    is              => 'rw',
+    is              => 'ro',
     isa             => 'Str',
     predicate       => 'has_raw',
 );
 
+has 'occurence' => (
+    is              => 'ro',
+    isa             => 'Int',
+    default         => sub { 1 },
+    traits          => ['Counter'],
+    handles         => {
+        inc_occurence   => 'inc',
+    }
+);
+
 sub original {
     my ($self) = @_;
     if ($self->has_raw) {
@@ -63,6 +74,34 @@ sub consume {
     return $self; 
 }
 
+sub full_value {
+    my ($self) = @_;
+    
+    # Fill up empty values
+    if ($self->has_values < $self->occurence) {
+        return [
+            $self->raw_values,
+            (undef) x ($self->occurence - $self->has_values)
+        ];
+    } else {
+        return $self->value;
+    }
+}
+
+#sub set_value {
+#    my ($self,$value) = @_;
+#    
+#    unless (scalar @{$self->value}) {
+#        $self->add_value($value);
+#    } else {
+#        if (! defined $self->value->[-1]) {
+#            $self->value->[-1] = $value;
+#        } else {
+#            $self->add_value($value);
+#        }
+#    }
+#}
+
 sub serialize {
     my ($self) = @_;
     given ($self->type) {
@@ -111,6 +150,10 @@ Raw value as supplied by the user
 
 Type of element. Can be 'option', 'parameter' or 'extra'
 
+=head2 occurence
+
+Number of occurences in @ARGV
+
 =head2 consumed
 
 Flag that indicates if element was already consumed
